@@ -60,7 +60,13 @@ class RegisterHtmlGenerator:
 <html>
 <head>
   <title>{title}</title>
-   <link rel="stylesheet" href="regs_style.css">
+    <!-- Include the style both inline and as a link to a separate CSS file. -->
+    <!-- Some tools, e.g. Jenkins, will not render with an external styleesheet. -->
+    <!-- For other tools, e.g. page inclusion in sphinx, the style must be in the file. -->
+    <link rel="stylesheet" href="regs_style.css">
+    <style>
+      {self.get_page_style()}
+    </style>
 </head>
 <body>
   <h1>{title}</h1>
@@ -107,12 +113,18 @@ table {
   border-collapse: collapse;
 }
 td, th {
-  border: 1px solid #ddd;
+  border-width: 1px;
+  border-style: solid;
+  border-color: #ddd;
   padding: 8px;
 }
 td.array_header {
-  background-color: #4cacaf;
-  color: white;
+  border-top-width: 10px;
+  border-top-color: #4cacaf;
+}
+td.array_footer {
+  border-bottom-width: 10px;
+  border-bottom-color: #4cacaf;
 }
 tr:nth-child(even) {
   background-color: #f2f2f2;
@@ -146,6 +158,30 @@ th {
         formatting_string = "0x{:0%iX}" % num_nibbles
         return formatting_string.format(value)
 
+    def _annotate_register_array(self, register_object):
+        description = self._html_translator.translate(register_object.description)
+        html = f"""
+  <tr>
+    <td class="array_header" colspan=5>
+      Register array <strong>{register_object.name}</strong>, \
+repeated {register_object.length} times.
+      Iterator <i>i &isin; [0, {register_object.length - 1}].</i>
+    </td>
+    <td class="array_header">{description}</td>
+  </tr>"""
+        array_index_increment = len(register_object.registers)
+        for register in register_object.registers:
+            register_index = register_object.base_index + register.index
+            html += self._annotate_register(register, register_index, array_index_increment)
+
+        html += f"""
+  <tr>
+    <td colspan="6" class="array_footer">
+      End register array <strong>{register_object.name}.</strong>
+    </td>
+  </tr>"""
+        return html
+
     def _annotate_register(self, register, register_array_index=None, array_index_increment=None):
         if register_array_index is None:
             address_readable = self._to_hex_string(register.address)
@@ -164,21 +200,24 @@ th {
     <td>{index}</td>
     <td>{address_readable}</td>
     <td>{REGISTER_MODES[register.mode].mode_readable}</td>
-    <td>{register.default_value}</td>
+    <td>{self._to_hex_string(register.default_value, num_nibbles=1)}</td>
     <td>{description}</td>
   </tr>"""
 
+        for field in register.fields:
+            html += self._annotate_field(field)
+
         return html
 
-    def _annotate_bit(self, bit):
-        description = self._html_translator.translate(bit.description)
+    def _annotate_field(self, field):
+        description = self._html_translator.translate(field.description)
         html = f"""
   <tr>
-    <td>&nbsp;&nbsp;<em>{bit.name}</em></td>
-    <td>&nbsp;&nbsp;{bit.index}</td>
-    <td></td>
+    <td>&nbsp;&nbsp;<em>{field.name}</em></td>
+    <td>&nbsp;&nbsp;{field.range}</td>
     <td></td>
     <td></td>
+    <td>{field.default_value_str}</td>
     <td>{description}</td>
   </tr>"""
 
@@ -202,28 +241,8 @@ th {
         for register_object in register_objects:
             if isinstance(register_object, Register):
                 html += self._annotate_register(register_object)
-                for bit in register_object.bits:
-                    html += self._annotate_bit(bit)
             else:
-                html += f"""
-  <tr>
-    <td colspan="6" class="array_header">
-      Register array <strong>{register_object.name}</strong>, \
-repeated {register_object.length} times
-    </td>
-  </tr>"""
-                array_index_increment = len(register_object.registers)
-                for register in register_object.registers:
-                    register_index = register_object.base_index + register.index
-                    html += self._annotate_register(register, register_index, array_index_increment)
-                    for bit in register.bits:
-                        html += self._annotate_bit(bit)
-                html += f"""
-  <tr>
-    <td colspan="6" class="array_header">
-      End register array <strong>{register_object.name}</strong>
-    </td>
-  </tr>"""
+                html += self._annotate_register_array(register_object)
 
         html += """
 </tbody>
