@@ -1,6 +1,10 @@
-# ------------------------------------------------------------------------------
+# --------------------------------------------------------------------------------------------------
 # Copyright (c) Lukas Vik. All rights reserved.
-# ------------------------------------------------------------------------------
+#
+# This file is part of the tsfpga project.
+# https://tsfpga.com
+# https://gitlab.com/tsfpga/tsfpga
+# --------------------------------------------------------------------------------------------------
 
 import pytest
 
@@ -17,12 +21,14 @@ def open_file_with_encoding(file):
 
 def test_all_checked_in_files_are_properly_encoded():
     """
-    To avoid problems with different editors and different file encodings, all checked in files should
-    contain only ASCII characters.
+    To avoid problems with different editors and different file encodings, all checked in files
+    should contain only ASCII characters.
 
     Avoid one of the documentation files that uses wonky characters to illustrate a directory tree.
     """
-    for file in files_to_test(exclude_directories=[tsfpga.TSFPGA_DOC / "sphinx" / "module_structure.rst"]):
+    for file in files_to_test(
+        exclude_directories=[tsfpga.TSFPGA_DOC / "sphinx" / "module_structure.rst"]
+    ):
         open_file_with_encoding(file)
 
 
@@ -54,7 +60,7 @@ def check_file_for_tab_character(file):
         for idx, line in enumerate(file_handle.readlines()):
             if "\t" in line:
                 test_ok = False
-                print("TAB charatcher (\\t) on line %i in %s" % (idx + 1, file))
+                print(f"TAB charatcher (\\t) on line {idx + 1} in {file}")
     return test_ok
 
 
@@ -81,7 +87,8 @@ def check_file_for_carriage_return(file):
 def test_no_checked_in_files_contain_carriage_return():
     """
     All checked in files should use UNIX style line breaks (\n not \r\n).
-    Some Linux editors and tools will display or interpret the \r as something other than a line break.
+    Some Linux editors and tools will display or interpret the \r as something other than a line
+    break.
     """
     test_ok = True
     for file in files_to_test():
@@ -95,14 +102,14 @@ def check_file_for_trailing_whitespace(file):
         for idx, line in enumerate(file_handle.readlines()):
             if " \n" in line:
                 test_ok = False
-                print("Trailing whitespace on line %i in %s" % (idx + 1, file))
+                print(f"Trailing whitespace on line {idx + 1} in {file}")
     return test_ok
 
 
 def test_no_checked_in_files_contain_trailing_whitespace():
     """
-    Trailing whitespace is not allowed.
-    Some motivation here: https://softwareengineering.stackexchange.com/questions/121555/why-is-trailing-whitespace-a-big-deal
+    Trailing whitespace is not allowed. Some motivation here:
+    https://softwareengineering.stackexchange.com/questions/121555/
     """
     test_ok = True
     for file in files_to_test():
@@ -112,7 +119,11 @@ def test_no_checked_in_files_contain_trailing_whitespace():
 
 def files_to_test(exclude_directories=None):
     # Do not test binary image files
-    return find_git_files(exclude_directories=exclude_directories, file_endings_avoid="png")
+    return find_git_files(
+        directory=tsfpga.REPO_ROOT,
+        exclude_directories=exclude_directories,
+        file_endings_avoid="png",
+    )
 
 
 def test_open_file_with_encoding_should_raise_exception_on_bad_file(tmp_path):
@@ -121,7 +132,8 @@ def test_open_file_with_encoding_should_raise_exception_on_bad_file(tmp_path):
     """
     file = tmp_path / "temp_file_for_test.txt"
     with file.open("w", encoding="utf-8") as file_handle:
-        data = "\N{LATIN CAPITAL LETTER O WITH DIAERESIS}"  # Swedish word for island = non-ASCII character
+        # Swedish word for island = non-ASCII character
+        data = "\N{LATIN CAPITAL LETTER O WITH DIAERESIS}"
         file_handle.write(data)
 
     with pytest.raises(UnicodeDecodeError):
