@@ -6,14 +6,16 @@
 # https://gitlab.com/tsfpga/tsfpga
 # --------------------------------------------------------------------------------------------------
 
-import json
+from copy import deepcopy
 import shutil
 
 from tsfpga import TSFPGA_TCL
 from tsfpga.system_utils import create_file, read_file
 from tsfpga.build_step_tcl_hook import BuildStepTclHook
+from .build_result import BuildResult
 from .common import run_vivado_tcl, run_vivado_gui
-from .size_checker import UtilizationParser
+from .hierarchical_utilization_parser import HierarchicalUtilizationParser
+from .logic_level_distribution_parser import LogicLevelDistributionParser
 from .tcl import VivadoTcl
 
 
@@ -80,6 +82,7 @@ class VivadoProject:
         # Will be set by child class when applicable
         self.is_netlist_build = False
         self.analyze_synthesis_timing = True
+        self.report_logic_level_distribution = False
 
         self.top = name + "_top" if top is None else top
         self._vivado_path = vivado_path
@@ -110,7 +113,7 @@ class VivadoProject:
         # Check the implemented timing and resource utilization via TCL build hooks.
         # This is different than for synthesis, where it is embedded in the build script.
         # This is due to Vivado limitations related to post-synthesis hooks.
-        # Spceifically, the report_utilization figures do not include IP cores when it is run in
+        # Specifically, the report_utilization figures do not include IP cores when it is run in
         # a post-synthesis hook.
         self.build_step_hooks.append(
             BuildStepTclHook(TSFPGA_TCL / "report_utilization.tcl", "STEPS.WRITE_BITSTREAM.TCL.PRE")
@@ -120,16 +123,27 @@ class VivadoProject:
         )
 
         if not self.analyze_synthesis_timing:
-            # In this special case however, the synthesized design is never opened. So in order to
-            # get a utiliztion report anyway we add it as a hook. This mode is exclusively used by
-            # netlist builds, which very rarely include IP cores, so it is acceptable that the
-            # utilization report might be erroneous with regards to IP cores.
+            # In this special case however, the synthesized design is never opened, and
+            # report_utilization is not run by the build_vivado_project.tcl.
+            # So in order to get a utilization report anyway we add it as a hook.
+            # This mode is exclusively used by netlist builds, which very rarely include IP cores,
+            # so it is acceptable that the utilization report might be erroneous with regards to
+            # IP cores.
             self.build_step_hooks.append(
                 BuildStepTclHook(
                     TSFPGA_TCL / "report_utilization.tcl", "STEPS.SYNTH_DESIGN.TCL.POST"
                 )
             )
 
+        if self.report_logic_level_distribution:
+            # Used by netlist builds
+            self.build_step_hooks.append(
+                BuildStepTclHook(
+                    TSFPGA_TCL / "report_logic_level_distribution.tcl",
+                    "STEPS.SYNTH_DESIGN.TCL.POST",
+                )
+            )
+
     def _create_tcl(self, project_path, ip_cache_path):
         """
         Make a TCL file that creates a Vivado project
@@ -172,6 +186,14 @@ class VivadoProject:
         self._setup_tcl_sources()
         self._setup_build_step_hooks()
 
+        # The pre-create hook migh have side effects. E.g. change some register constants.
+        # So we make a deep copy of the module list before the hook is called.
+        # Note that the modules are copied before the pre-build hooks as well,
+        # since we do not know if we might be performing a create-only or
+        # build-only operation. The copy does not take any significant time, so this is not
+        # an issue.
+        self.modules = deepcopy(self.modules)
+
         if not self.pre_create(project_path=project_path, ip_cache_path=ip_cache_path):
             print("ERROR: Project pre-create hook returned False. Failing the build.")
             return False
@@ -215,9 +237,10 @@ class VivadoProject:
         elif generics is None:
             all_generics = self.static_generics
         else:
-            # Add the two dictionaries
-            all_generics = self.static_generics.copy()
-            all_generics.update(generics)
+            # Add the two dictionaries. This will prefer the values in the run-time generics,
+            # if the same generic is present in both.
+            all_generics = generics
+            all_generics.update(self.static_generics)
 
         build_vivado_project_tcl = project_path / "build_vivado_project.tcl"
         tcl = self.tcl.build(
@@ -300,7 +323,7 @@ class VivadoProject:
                     This is a "kwargs" style argument. You can pass any number of named arguments.
 
         Return:
-            BuildResult: Result object with build information.
+            :class:`.build_result.BuildResult`: Result object with build information.
         """
         synth_only = synth_only or self.is_netlist_build
 
@@ -325,6 +348,14 @@ class VivadoProject:
             num_threads=num_threads,
         )
 
+        # The pre-build hooks (either project pre-build hook or any of the module's pre-build hooks)
+        # migh have side effects. E.g. change some register constants. So we make a deep copy of the
+        # module list before any of these hooks are called. Note that the modules are copied before
+        # the pre-create hook as well, since we do not know if we might be performing a create-only
+        # or build-only operation. The copy does not take any significant time, so this is not
+        # an issue.
+        self.modules = deepcopy(self.modules)
+
         result = BuildResult(self.name)
 
         for module in self.modules:
@@ -357,6 +388,10 @@ class VivadoProject:
             return result
 
         result.synthesis_size = self._get_size(project_path, f"synth_{run_index}")
+        if self.report_logic_level_distribution:
+            result.logic_level_distribution = self._get_logic_level_distribution(
+                project_path, f"synth_{run_index}"
+            )
 
         if not synth_only:
             impl_folder = project_path / f"{self.name}.runs" / f"impl_{run_index}"
@@ -393,7 +428,17 @@ class VivadoProject:
         report_as_string = read_file(
             project_path / f"{self.name}.runs" / run / "hierarchical_utilization.rpt"
         )
-        return UtilizationParser.get_size(report_as_string)
+        return HierarchicalUtilizationParser.get_size(report_as_string)
+
+    def _get_logic_level_distribution(self, project_path, run):
+        """
+        Reads the hierarchical utilization report and returns the top level size
+        for the specified run.
+        """
+        report_as_string = read_file(
+            project_path / f"{self.name}.runs" / run / "logical_level_distribution.rpt"
+        )
+        return LogicLevelDistributionParser.get_table(report_as_string)
 
     def __str__(self):
         result = self.name
@@ -417,7 +462,7 @@ class VivadoNetlistProject(VivadoProject):
     Used for handling Vivado build of a module without top level pinning.
     """
 
-    def __init__(self, analyze_synthesis_timing=False, result_size_checkers=None, **kwargs):
+    def __init__(self, analyze_synthesis_timing=False, build_result_checkers=None, **kwargs):
         """
         Arguments:
             analyze_synthesis_timing (bool): Enable analysis of the synthesized design's timing.
@@ -426,16 +471,17 @@ class VivadoNetlistProject(VivadoProject):
                 Enabling it will add significant build time (can be as much as +40%).
                 Also, in order for clock crossing check to work, the clocks have to be created
                 using a constraint file.
-            result_size_checkers (list(:class:`.SizeChecker`)): Size checkers that will be
-                executed after a succesful build. Is used to automatically check that
-                resource utilization is not greater than expected.
+            build_result_checkers (list(:class:`.SizeChecker`, :class:`.MaximumLogicLevel`)):
+                Checkers that will be executed after a successful build. Is used to automatically
+                check that e.g. resource utilization is not greater than expected.
             kwargs: Other arguments accepted by :meth:`.VivadoProject.__init__`.
         """
         super().__init__(**kwargs)
 
         self.is_netlist_build = True
         self.analyze_synthesis_timing = analyze_synthesis_timing
-        self.result_size_checkers = [] if result_size_checkers is None else result_size_checkers
+        self.report_logic_level_distribution = True
+        self.build_result_checkers = [] if build_result_checkers is None else build_result_checkers
 
     def build(self, **kwargs):  # pylint: disable=arguments-differ
         """
@@ -451,56 +497,12 @@ class VivadoNetlistProject(VivadoProject):
 
     def _check_size(self, build_result):
         if not build_result.success:
-            print(f"Can not do post_build size check for {self.name} since it did not succeed.")
+            print(f"Can not do post_build check for {self.name} since it did not succeed.")
             return False
 
         success = True
-        for result_size_checker in self.result_size_checkers:
-            result = result_size_checker.check(build_result.synthesis_size)
-            success = success and result
+        for build_result_checker in self.build_result_checkers:
+            checker_result = build_result_checker.check(build_result)
+            success = success and checker_result
 
         return success
-
-
-class BuildResult:
-
-    """
-    Attributes:
-        project_name (`str`): The name of the build.
-        success (`bool`): True if the build and all pre- and post hooks succeeded.
-        synthesis_size (`dict`): A dictionary with the utilization of primitives for the
-            synthesized design. Will be ``None`` if synthesis failed or did not run.
-        implementation_size (`dict`): A dictionary with the utilization of primitives for
-            the implemented design. Will be ``None`` if implementation failed or did not run.
-    """
-
-    def __init__(self, name):
-        """
-        Arguments:
-            name (`str`): The name of the build.
-        """
-        self.name = name
-        self.success = True
-        self.synthesis_size = None
-        self.implementation_size = None
-
-    def size_summary(self):
-        """
-        Return a string with a formatted message of the size.
-
-        Returns:
-            str: A human-readable message of the latest size. ``None`` if no size is set.
-        """
-        build_step = None
-        size = None
-
-        if self.implementation_size is not None:
-            build_step = "implementation"
-            size = self.implementation_size
-        elif self.synthesis_size is not None:
-            build_step = "synthesis"
-            size = self.synthesis_size
-        else:
-            return None
-
-        return f"Size of {self.name} after {build_step}:\n{json.dumps(size, indent=2)}"
