@@ -1,6 +1,10 @@
-# ------------------------------------------------------------------------------
+# --------------------------------------------------------------------------------------------------
 # Copyright (c) Lukas Vik. All rights reserved.
-# ------------------------------------------------------------------------------
+#
+# This file is part of the tsfpga project.
+# https://tsfpga.com
+# https://gitlab.com/tsfpga/tsfpga
+# --------------------------------------------------------------------------------------------------
 
 import re
 import subprocess
@@ -21,7 +25,7 @@ class VivadoSimlibGhdl(VivadoSimlibCommon):
 
     def __init__(self, output_path, vunit_proj, simulator_interface, vivado_path):
         """
-        Args:
+        Arguments:
             output_path (`pathlib.Path`): The compiled simlib will be placed here.
             vunit_proj: The VUnit project that is used to run simulation.
             simulator_interface: A VUnit SimulatorInterface class.
@@ -43,7 +47,10 @@ class VivadoSimlibGhdl(VivadoSimlibCommon):
         self._compile_unifast(vivado_libraries_path / "unifast" / "primitive")
 
     def _compile_unisim(self, library_path):
-        for vhd_file_base in ["unisim_VPKG", "unisim_VCOMP", "retarget_VCOMP", "unisim_retarget_VCOMP"]:
+        for vhd_file_base in [
+            "unisim_VPKG",
+            "unisim_retarget_VCOMP",
+        ]:
             vhd_file = library_path / (vhd_file_base + ".vhd")
             assert vhd_file.exists, vhd_file
             self._compile_ghdl_file(vhd_file, "unisim")
@@ -97,7 +104,7 @@ class VivadoSimlibGhdl(VivadoSimlibCommon):
             "--warn-binding",
             "--mb-comments",
             "--work=" + library_name,
-            str(vhd_file.resolve())
+            str(vhd_file.resolve()),
         ]
         subprocess.check_call(cmd, cwd=self._output_path)
 
